@@ -29,7 +29,7 @@ class FullScreenTextarea(Textarea):
     class Media:
         css = {
             'screen': (
-                '//fonts.googleapis.com/css?family=Lato',
+                '//fonts.googleapis.com/css?family=Roboto',
                 'writingfield/writingfield.css',)
         }
         js = (
